python-minecraft-data
=====================

|pypi|_

Provide easy access to `minecraft-data <https://github.com/PrismarineJS/minecraft-data>`__ in python

Installation
------------
From PyPi:

``pip install minecraft_data``

From Repo:

``python -m pip install git+https://github.com/SpockBotMC/python-minecraft-data``

Usage
-----

See the `example.py <https://github.com/rom1504/python-minecraft-data/blob/master/example.py>`__


Documentation
-------------

- See `doc/api.md <https://github.com/rom1504/python-minecraft-data/blob/master/doc/api.md>`__
- See `doc/history.md <https://github.com/rom1504/python-minecraft-data/blob/master/doc/history.md>`__


.. |pypi| image:: https://img.shields.io/pypi/v/minecraft_data.svg
.. _pypi: https://pypi.python.org/pypi/minecraft_data
